==> mysql-workbench_6.1.7%2Bdfsg.orig.tar.xz: mysql-workbench-6.1.7/library/forms/unit-tests/utilities_test.cpp <==
/* 
 * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */

#include "tut_stdafx.h"

#include "test.h"
#include "mforms/utilities.h"
#include "forms/stub/stub_mforms.h"

using namespace mforms;

BEGIN_TEST_DATA_CLASS(mforms_utilities_test)
END_TEST_DATA_CLASS;

TEST_MODULE(mforms_utilities_test, "mforms utilities testing");

TEST_FUNCTION(1)
{

  mforms::stub::init(NULL);
  
  std::string service= "A quick brown fox jumps over the lazy dog. ";
  std::string user_name= "father abraham";
  std::string the_password= "!$%&dingeling 123@";

  std::string result;
  ensure("Reading non-existing password", !Utilities::find_password("out of service", "don't call me, I call you", result));
  Utilities::store_password(service, user_name, the_password);//ensure("Writing a password", Utilities::store_password(service, user_name, the_password));
  ensure("Reading password back", Utilities::find_password(service, user_name, result));
  ensure_equals("Comparing returned to stored password", the_password, result);

}

END_TESTS

==> mysql-workbench_6.2.3%2Bdfsg.orig.tar.xz: mysql-workbench-6.2.3/library/forms/unit-tests/utilities_test.cpp <==
/* 
 * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */

#include "test.h"
#include "mforms/utilities.h"
#include "stub/stub_mforms.h"

using namespace mforms;

BEGIN_TEST_DATA_CLASS(mforms_utilities_test)
END_TEST_DATA_CLASS;

TEST_MODULE(mforms_utilities_test, "mforms utilities testing");

TEST_FUNCTION(1)
{

  mforms::stub::init(NULL);
  
  std::string service= "A quick brown fox jumps over the lazy dog. ";
  std::string user_name= "father abraham";
  std::string the_password= "!$%&dingeling 123@";

  std::string result;
  ensure("Reading non-existing password", !Utilities::find_password("out of service", "don't call me, I call you", result));
  Utilities::store_password(service, user_name, the_password);//ensure("Writing a password", Utilities::store_password(service, user_name, the_password));
  ensure("Reading password back", Utilities::find_password(service, user_name, result));
  ensure_equals("Comparing returned to stored password", the_password, result);

}

END_TESTS
